package org.jpereda.charm;

import com.gluonhq.charm.down.common.JavaFXPlatform;
import com.gluonhq.charm.glisten.application.MobileApplication;
import static com.gluonhq.charm.glisten.application.MobileApplication.HOME_VIEW;
import com.gluonhq.charm.glisten.mvc.View;
import com.gluonhq.charm.glisten.visual.Swatch;
import javafx.beans.value.ObservableValue;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.geometry.Pos;
import javafx.scene.control.ComboBox;
import javafx.scene.control.Label;
import javafx.scene.control.Spinner;

import javafx.scene.control.SpinnerValueFactory.ListSpinnerValueFactory;
import javafx.scene.control.ToolBar;
import javafx.scene.layout.VBox;

/**
 * Simple application for getting started with Gluon Charm 
 * 
 * More here: http://gluonhq.com/products/charm/
 * 
 * @author Jose Pereda @JPeredaDnr
 */
public class HelloCharm extends MobileApplication {
    
    private final Label labelDialog = new Label();
    private final Label labelCheck = new Label();
    private ToolBar homeToolbar;
    
    @Override
    public void init() throws Exception {
        super.init(); 
        
        /*
        Create default home view
        */
        addViewFactory(HOME_VIEW, ()->{
            View home = new View("Home View");
            
            VBox vBox = new VBox(20,new Label("Hello Charm!"),labelDialog,labelCheck);
            vBox.setAlignment(Pos.CENTER);
            
            ComboBox<String> cBox;
            cBox = new ComboBox<>();
            cBox.getItems().add("Eins");
            cBox.getItems().add("Zwei");
            cBox.getItems().add("Drei");
            cBox.valueProperty().addListener((ObservableValue<? extends String> observable, String oldValue, String newValue) -> {
                vBox.getChildren().add(new Label("ComboBox: " + newValue));
                System.err.println("ComboBox ChangeListener");
            });
            Spinner<String> spinner = new Spinner<>();
            ObservableList<String> spinnerItems = FXCollections.observableArrayList();
            spinnerItems.add("Eins");
            spinnerItems.add("Zwo");
            spinnerItems.add("Drei");
            spinner.valueFactoryProperty().set(new ListSpinnerValueFactory<>(spinnerItems));
            spinner.valueProperty().addListener((ObservableValue<? extends String> observable, String oldValue, String newValue) -> {
                vBox.getChildren().add(new Label("Spinner: " + newValue));
                System.err.println("spinner ChangeListener");
            });
            vBox.getChildren().add(cBox);
            vBox.getChildren().add(spinner);
            
            home.setCenter(vBox);
            
            /*
            JavaFX thread
            */
            home.showingProperty().addListener((obs,b,b1)->{
                if(b1){
                    home.setSwatch(Swatch.AMBER);
                    
                    if(JavaFXPlatform.isDesktop()){
                        home.getScene().getWindow().setWidth(400);
                        home.getScene().getWindow().setHeight(700);
                    }
                }
            });
            
            return home;
        });
    }   
}
