package com.sample.controllers;

import java.io.IOException;
import java.net.URL;
import java.util.ResourceBundle;

import javafx.event.EventHandler;
import javafx.fxml.FXMLLoader;
import javafx.fxml.Initializable;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.input.KeyCode;
import javafx.scene.input.KeyEvent;
import javafx.stage.Modality;
import javafx.stage.Stage;
import javafx.stage.StageStyle;

import com.sample.pack.Main;

abstract public class Controller implements Initializable {

	protected Scene scene;
	protected Stage stage;

	protected ResourceBundle translator;

	// ==========================================================================

	@Override
	public void initialize(final URL location, final ResourceBundle resources) {

		translator = resources;
	}

	// ==========================================================================

	public void setSceneAndStage(final Scene sc, final Stage st) {

		scene = sc;
		stage = st;

		// zatvori scene
		scene.addEventFilter(KeyEvent.KEY_PRESSED, new EventHandler<KeyEvent>() {

			@Override
			public void handle(final KeyEvent event) {

				if (event.getCode().equals(KeyCode.ESCAPE)) {

					Main.runAndWait(new Runnable() {

						@Override
						public void run() {

							close();
						}
					});
				}
			}
		});
	}

	// ==========================================================================

	public void close() {

		stage.hide();
	}

	// ==========================================================================

	public static <T extends Controller> void showNewModalWindow(final String fxmlPath) {

		final FXMLLoader loader = new FXMLLoader(Main.getInstance().getClass().getResource(fxmlPath), Main.getInstance().getTranslator());

		Parent rootTemp = null;
		try {

			rootTemp = (Parent) loader.load();
		}
		catch (final IOException e) {

			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		final Parent root = rootTemp;

		Main.runAndWait(new Runnable() {

			@Override
			public void run() {

				final Scene scene = new Scene(root);

				final Stage stage = new Stage();
				stage.setScene(scene);
				stage.initStyle(StageStyle.UNDECORATED);
				stage.initModality(Modality.WINDOW_MODAL);

				final T controller = loader.getController();
				controller.setSceneAndStage(scene, stage);

				CtrMain.getInstance().setBlur(true);
				stage.show();
			}
		});
	}
}
