package com.sample.pack;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.Locale;
import java.util.ResourceBundle;
import java.util.concurrent.CountDownLatch;

import javafx.application.Application;
import javafx.application.Platform;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.control.ContextMenu;
import javafx.scene.control.MenuItem;
import javafx.scene.input.KeyCode;
import javafx.scene.input.KeyEvent;
import javafx.scene.layout.GridPane;
import javafx.stage.Screen;
import javafx.stage.Stage;
import javafxports.android.FXActivity;
import android.content.Context;
import android.util.Log;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.Toast;

import com.sample.controllers.Controller;
import com.sample.controllers.CtrMain;

public final class Main extends Application {

	@SuppressWarnings("unused") private static final String TAG = "MAIN";
	@SuppressWarnings("unused") private static final boolean D = true;

	private static Main instance;
	private static final String fxmlMain = "/com/sample/res/fxml/Main.fxml";
	private Stage mainStage;

	private final ContextMenu optionsMenu = new ContextMenu();

	private ResourceBundle translator;

	// ==========================================================================

	public Main() {

		instance = this;
	}

	// ==========================================================================

	public static Main getInstance() {

		return instance;
	}

	// ==========================================================================

	public ResourceBundle getTranslator() {

		return translator;
	}

	// ==========================================================================

	public Stage getMainStage() {

		return mainStage;
	}

	// ==========================================================================

	@Override
	public void start(final Stage primaryStage) {

		//		 setUserAgentStylesheet(STYLESHEET_CASPIAN);

		GridPane page;

		try {

			final Locale locale = new Locale("en", "US");
			translator = ResourceBundle.getBundle("com.sample.res.Bundle", locale);

			createOptionsMenu();

			//			final double rem = Math.rint(new Text("").getLayoutBounds().getHeight());

			page = (GridPane) FXMLLoader.load(Main.class.getResource(fxmlMain), translator);
			//			final Scene scene = new Scene(page, 160 * rem, 100 * rem);
			final Scene scene = new Scene(page);

			// prida udalosti na stlacenie "tlacitiek" (virtualnych)
			scene.addEventHandler(KeyEvent.KEY_PRESSED, new EventHandler<KeyEvent>() {

				@Override
				public void handle(final KeyEvent event) {

					Log.d("KEY", event.getCode().getName());

					if (event.getCode().equals(KeyCode.ESCAPE)) {

						CtrMain.getInstance().close();
					}
					else if (event.getCode().equals(KeyCode.CONTEXT_MENU)) {

						runAndWait(new Runnable() {

							@Override
							public void run() {

								Log.d("SHOW", "menu");
								optionsMenu.show(mainStage, Screen.getPrimary().getVisualBounds().getWidth(), Screen.getPrimary().getVisualBounds().getHeight());
							}
						});
					}
				}
			});

			mainStage = primaryStage;
			primaryStage.setTitle("Sample");
			primaryStage.setMaximized(true);
			primaryStage.setScene(scene);
			primaryStage.show();
		}
		catch (final IOException e) {

			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	// ==========================================================================

	private void createOptionsMenu() {

		final MenuItem cmItemSettings = new MenuItem(translator.getString("options_menu_settings"));
		optionsMenu.getItems().add(cmItemSettings);
		cmItemSettings.setOnAction(showOptions);
	}

	// ==========================================================================

	public static void main(final String[] args) {

		launch(args);
	}

	// ==========================================================================
	// EventHandler
	// ==========================================================================

	final EventHandler<ActionEvent> showOptions = new EventHandler<ActionEvent>() {

		@Override
		public void handle(final ActionEvent event) {

			Controller.showNewModalWindow("/com/sample/res/fxml/SetGen.fxml");
		}
	};

	// ==========================================================================
	// utility
	// ==========================================================================

	/**
	 * Runs the specified {@link Runnable} on the
	 * JavaFX application thread and waits for completion.
	 *
	 * @param action the {@link Runnable} to run
	 * @throws NullPointerException if {@code action} is {@code null}
	 */
	public static void runAndWait(final Runnable action) {

		if (action == null) {

			throw new NullPointerException("action");
		}

		// run synchronously on JavaFX thread
		if (Platform.isFxApplicationThread()) {

			action.run();
			return;
		}

		// queue on JavaFX thread and wait for completion
		final CountDownLatch doneLatch = new CountDownLatch(1);

		Platform.runLater(() -> {

			try {

				action.run();
			}
			finally {

				doneLatch.countDown();
			}
		});

		try {

			doneLatch.await();
		}
		catch (final InterruptedException e) {
			// ignore exception
		}
	}
}
